intelmq.bots.outputs.sql package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.sql package

## Submodules

## intelmq.bots.outputs.sql.output module

SQL output bot.

See bot sql bot documentation for installation and configuration.

In case of errors, the bot tries to reconnect if the error is of operational and thus temporary. We don’t want to catch too much, like programming errors (missing fields etc).

intelmq.bots.outputs.sql.output.BOT

  alias of `intelmq.bots.outputs.sql.output.SQLOutputBot`

class intelmq.bots.outputs.sql.output.SQLOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`, `intelmq.lib.mixins.sql.SQLMixin`

  Send events to a PostgreSQL or SQLite database

  autocommit = True
  database = 'intelmq-events'
  engine = None
  host = 'localhost'
  init()
  jsondict_as_string: bool = True
  password = None
  port = '5432'
  process()
  sslmode = 'require'
  table = 'events'
  user = 'intelmq'

## Module contents